#ifndef NT2_INCLUDE_FUNCTIONS_IS_GREATER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_GREATER_HPP_INCLUDED

#include <nt2/operator/include/functions/is_greater.hpp>

#endif
